@@ -13,12 +13,40 @@
 //#include <QtOpenGL/QGLWidget>
 //#endif
 
+static QNetworkCookieJar *jar = new QNetworkCookieJar();
+
+class MyNetworkAccessManagerFactory : public QDeclarativeNetworkAccessManagerFactory
+{
+public:
+    virtual QNetworkAccessManager *create(QObject *parent);
+};
+
+QNetworkAccessManager *MyNetworkAccessManagerFactory::create(QObject *parent = 0)
+{
+    QNetworkAccessManager *nam = new QNetworkAccessManager(parent);
+
+    nam->setCookieJar(jar);
+    return nam;
+}
+
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);   
     Controller ct;
     YouTube yt;
 
+    QStringList proxyList = ct.getProxyFromDB();
+    QString proxyHost = proxyList.first();
+    if (!proxyHost.isEmpty()) {
+        int proxyPort = proxyList.last().toInt();
+        QNetworkProxy proxy;
+        proxy.setType(QNetworkProxy::HttpCachingProxy);
+        proxy.setHostName(proxyHost);
+        proxy.setPort(proxyPort);
+        QNetworkProxy::setApplicationProxy(proxy);
+    }
+
     QStringList args = app.arguments();
     args.takeFirst();
     if (args.isEmpty()) {
@@ -29,10 +57,13 @@ int main(int argc, char *argv[])
         ct.setView(&viewer);
         Sharing sh;
         DownloadManager dm;
-        QNetworkAccessManager *manager = new QNetworkAccessManager();
+
+        MyNetworkAccessManagerFactory *factory = new MyNetworkAccessManagerFactory;
+        QNetworkAccessManager *manager = factory->create();
         yt.setNetworkAccessManager(manager);
         dm.setNetworkAccessManager(manager);
         sh.setNetworkAccessManager(manager);
+
         context->setContextProperty("Controller", &ct);
         context->setContextProperty("DownloadManager", &dm);
         context->setContextProperty("YouTube", &yt);
@@ -40,8 +71,10 @@ int main(int argc, char *argv[])
 
         qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
+        viewer.engine()->setNetworkAccessManagerFactory(factory);
+
 #ifdef Q_WS_MAEMO_5
-        //    viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
+//        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
         //    viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
         QDir path;
@@ -74,10 +107,10 @@ int main(int argc, char *argv[])
         /* Get the video URL and play the video */
 
         QString playerUrl = args.at(1);
-        QString quality = "High Quality";
+        QString quality = "hq";
         if (args.length() > 2) {
             if (args.at(2) == "m") {
-                quality = "Mobile";
+                quality = "mobile";
             }
         }
         ct.getMediaPlayerFromDB();
@@ -90,6 +123,7 @@ int main(int argc, char *argv[])
         app.exec();
     }
     else {
-        return 0;
+        qWarning() << "Invalid arguments";
+        exit(1);
     }
 }
