@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.6.5</source>
+        <source>cuteTube-QML - 0.7.0</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -95,19 +95,15 @@
 <context>
     <name>ArchiveListView</name>
     <message>
-        <location filename="../ArchiveListView.qml" line="72"/>
-        <source>Multi-select</source>
-        <translation></translation>
+        <location filename="../ArchiveListView.qml" line="17"/>
+        <source>Deleted from archive</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="74"/>
-        <source>Delete from archive</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../ArchiveListView.qml" line="74"/>
-        <source>Delete from device</source>
-        <translation></translation>
+        <location filename="../ArchiveListView.qml" line="20"/>
+        <location filename="../ArchiveListView.qml" line="35"/>
+        <source>Unable to delete from archive</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -167,22 +163,22 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="181"/>
+        <location filename="../../../controller.cpp" line="188"/>
         <source>Video deleted from device</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="184"/>
+        <location filename="../../../controller.cpp" line="191"/>
         <source>Unable to delete video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="188"/>
+        <location filename="../../../controller.cpp" line="195"/>
         <source>Video not found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="243"/>
+        <location filename="../../../controller.cpp" line="250"/>
         <source>Copied to clipboard</source>
         <translation></translation>
     </message>
@@ -198,98 +194,60 @@
 <context>
     <name>HomeView</name>
     <message>
-        <location filename="../HomeView.qml" line="102"/>
-        <source>Settings</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../HomeView.qml" line="102"/>
-        <source>Accounts</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../HomeView.qml" line="102"/>
-        <source>About</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../HomeView.qml" line="154"/>
+        <location filename="../HomeView.qml" line="119"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="178"/>
+        <location filename="../HomeView.qml" line="143"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="202"/>
+        <location filename="../HomeView.qml" line="167"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="226"/>
+        <location filename="../HomeView.qml" line="191"/>
         <source>Archive</source>
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>MenuBar</name>
-    <message>
-        <location filename="../MenuBar.qml" line="24"/>
-        <source>Menu</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../MenuBar.qml" line="45"/>
-        <source>Back</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../MenuBar.qml" line="57"/>
-        <source>Exit</source>
-        <translation></translation>
-    </message>
-</context>
 <context>
     <name>MyAccountView</name>
     <message>
-        <location filename="../MyAccountView.qml" line="72"/>
-        <source>Upload video</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../MyAccountView.qml" line="112"/>
+        <location filename="../MyAccountView.qml" line="81"/>
         <source>My Uploads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="118"/>
+        <location filename="../MyAccountView.qml" line="87"/>
         <source>Uploads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="136"/>
+        <location filename="../MyAccountView.qml" line="105"/>
         <source>My Favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="142"/>
+        <location filename="../MyAccountView.qml" line="111"/>
         <source>Favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="166"/>
+        <location filename="../MyAccountView.qml" line="135"/>
         <source>Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="190"/>
+        <location filename="../MyAccountView.qml" line="159"/>
         <source>Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="205"/>
+        <location filename="../MyAccountView.qml" line="174"/>
         <source>Signed in as:</source>
         <translation></translation>
     </message>
@@ -382,37 +340,7 @@
 <context>
     <name>PlaylistVideosView</name>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="60"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistVideosView.qml" line="62"/>
-        <source>Download video</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistVideosView.qml" line="62"/>
-        <source>Download audio</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistVideosView.qml" line="63"/>
-        <source>Add to favourites</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistVideosView.qml" line="63"/>
-        <source>Add to playlist</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistVideosView.qml" line="63"/>
-        <source>Copy to clipboard</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistVideosView.qml" line="117"/>
+        <location filename="../PlaylistVideosView.qml" line="75"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
@@ -420,17 +348,12 @@
 <context>
     <name>PlaylistsView</name>
     <message>
-        <location filename="../PlaylistsView.qml" line="61"/>
+        <location filename="../PlaylistsView.qml" line="58"/>
         <source>New playlist created</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistsView.qml" line="109"/>
-        <source>New playlist</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../PlaylistsView.qml" line="137"/>
+        <location filename="../PlaylistsView.qml" line="106"/>
         <source>No playlists found</source>
         <translation></translation>
     </message>
@@ -476,7 +399,7 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="183"/>
+        <location filename="../SearchBar.qml" line="181"/>
         <source>Order by:</source>
         <translation></translation>
     </message>
@@ -484,54 +407,54 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="189"/>
+        <location filename="../SettingsDialog.qml" line="192"/>
         <source>Your saved searches have been cleared</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="192"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Database error. Unable to clear searches</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="239"/>
+        <location filename="../SettingsDialog.qml" line="242"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="280"/>
+        <location filename="../SettingsDialog.qml" line="283"/>
         <source>Playback quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="288"/>
+        <location filename="../SettingsDialog.qml" line="291"/>
         <source>Download quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="296"/>
+        <location filename="../SettingsDialog.qml" line="299"/>
         <source>Start downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="304"/>
+        <location filename="../SettingsDialog.qml" line="307"/>
         <source>Download location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="320"/>
+        <location filename="../SettingsDialog.qml" line="323"/>
         <source>Screen orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="328"/>
+        <location filename="../SettingsDialog.qml" line="331"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="165"/>
-        <location filename="../SettingsDialog.qml" line="345"/>
-        <location filename="../SettingsDialog.qml" line="537"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="348"/>
+        <location filename="../SettingsDialog.qml" line="540"/>
         <source>Language</source>
         <translation></translation>
     </message>
@@ -577,38 +500,38 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="117"/>
-        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="120"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
         <source>Network Proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="141"/>
-        <location filename="../SettingsDialog.qml" line="391"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
+        <location filename="../SettingsDialog.qml" line="394"/>
         <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
-        <location filename="../SettingsDialog.qml" line="409"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Download Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
-        <location filename="../SettingsDialog.qml" line="427"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="156"/>
-        <location filename="../SettingsDialog.qml" line="483"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="486"/>
         <source>Screen Orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="159"/>
-        <location filename="../SettingsDialog.qml" line="501"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="504"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
@@ -618,6 +541,21 @@
         <source>Mobile</source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>360p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>480p</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <source>720p</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="39"/>
         <source>Automatically</source>
@@ -694,95 +632,95 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="102"/>
+        <location filename="../SettingsDialog.qml" line="105"/>
         <source>Your settings have been saved</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
-        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
         <source>Download Path</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="109"/>
+        <location filename="../SettingsDialog.qml" line="112"/>
         <source>Download Location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="153"/>
-        <location filename="../SettingsDialog.qml" line="465"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
+        <location filename="../SettingsDialog.qml" line="468"/>
         <source>Safe Search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="162"/>
-        <location filename="../SettingsDialog.qml" line="336"/>
-        <location filename="../SettingsDialog.qml" line="519"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="339"/>
+        <location filename="../SettingsDialog.qml" line="522"/>
         <source>Theme</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="171"/>
-        <location filename="../SettingsDialog.qml" line="619"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
+        <location filename="../SettingsDialog.qml" line="623"/>
         <source>Widget Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="174"/>
-        <location filename="../SettingsDialog.qml" line="639"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="643"/>
         <source>Widget Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
-        <location filename="../SettingsDialog.qml" line="659"/>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="663"/>
         <source>Widget Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="180"/>
-        <location filename="../SettingsDialog.qml" line="679"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="683"/>
         <source>Widget Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="272"/>
+        <location filename="../SettingsDialog.qml" line="275"/>
         <source>Network proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="315"/>
         <source>Safe search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="364"/>
+        <location filename="../SettingsDialog.qml" line="367"/>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="568"/>
+        <location filename="../SettingsDialog.qml" line="572"/>
         <source>Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="576"/>
+        <location filename="../SettingsDialog.qml" line="580"/>
         <source>Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="584"/>
+        <location filename="../SettingsDialog.qml" line="588"/>
         <source>Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="592"/>
+        <location filename="../SettingsDialog.qml" line="596"/>
         <source>Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="694"/>
+        <location filename="../SettingsDialog.qml" line="698"/>
         <source>Clear saved searches</source>
         <translation></translation>
     </message>
@@ -798,18 +736,17 @@
 <context>
     <name>SubscriptionsView</name>
     <message>
-        <location filename="../SubscriptionsView.qml" line="46"/>
+        <location filename="../SubscriptionsView.qml" line="36"/>
+        <source>Latest Subscriptions Videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SubscriptionsView.qml" line="45"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="105"/>
-        <location filename="../SubscriptionsView.qml" line="120"/>
-        <source>Latest Subscription Videos</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SubscriptionsView.qml" line="133"/>
+        <location filename="../SubscriptionsView.qml" line="104"/>
         <source>No subscriptions found</source>
         <translation></translation>
     </message>
@@ -991,67 +928,37 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="98"/>
+        <location filename="../UserVideosView.qml" line="115"/>
         <source>You have subscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="102"/>
+        <location filename="../UserVideosView.qml" line="119"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="124"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../UserVideosView.qml" line="126"/>
-        <source>Download video</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../UserVideosView.qml" line="126"/>
-        <source>Download audio</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../UserVideosView.qml" line="127"/>
-        <source>Add to favourites</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../UserVideosView.qml" line="127"/>
-        <source>Add to playlist</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../UserVideosView.qml" line="127"/>
-        <source>Copy to clipboard</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../UserVideosView.qml" line="180"/>
+        <location filename="../UserVideosView.qml" line="139"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="239"/>
+        <location filename="../UserVideosView.qml" line="198"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="253"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="276"/>
+        <location filename="../UserVideosView.qml" line="235"/>
         <source>Unsubscribe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="276"/>
+        <location filename="../UserVideosView.qml" line="235"/>
         <source>Subscribe</source>
         <translation></translation>
     </message>
@@ -1059,108 +966,86 @@
 <context>
     <name>VideoInfoView</name>
     <message>
-        <location filename="../VideoInfoView.qml" line="16"/>
+        <location filename="../VideoInfoView.qml" line="15"/>
         <source>No description</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="71"/>
+        <location filename="../VideoInfoView.qml" line="92"/>
         <source>Your comment has been added</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="74"/>
+        <location filename="../VideoInfoView.qml" line="95"/>
         <source>Your rating has been added</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="81"/>
+        <location filename="../VideoInfoView.qml" line="102"/>
         <source>Video shared on facebook</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="103"/>
-        <source>Add to favourites</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoInfoView.qml" line="103"/>
-        <source>Add to playlist</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoInfoView.qml" line="103"/>
-        <source>Copy to clipboard</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoInfoView.qml" line="104"/>
-        <source>Share via facebook</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoInfoView.qml" line="123"/>
-        <location filename="../VideoInfoView.qml" line="131"/>
-        <location filename="../VideoInfoView.qml" line="470"/>
-        <location filename="../VideoInfoView.qml" line="494"/>
-        <location filename="../VideoInfoView.qml" line="599"/>
+        <location filename="../VideoInfoView.qml" line="443"/>
+        <location filename="../VideoInfoView.qml" line="467"/>
+        <location filename="../VideoInfoView.qml" line="572"/>
         <source>You are not signed in to a YouTube account</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="271"/>
+        <location filename="../VideoInfoView.qml" line="244"/>
         <source>Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="310"/>
+        <location filename="../VideoInfoView.qml" line="283"/>
         <source>Comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="349"/>
+        <location filename="../VideoInfoView.qml" line="322"/>
         <source>Related</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="440"/>
-        <location filename="../VideoInfoView.qml" line="443"/>
+        <location filename="../VideoInfoView.qml" line="413"/>
+        <location filename="../VideoInfoView.qml" line="416"/>
         <source>By </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="442"/>
-        <location filename="../VideoInfoView.qml" line="445"/>
+        <location filename="../VideoInfoView.qml" line="415"/>
+        <location filename="../VideoInfoView.qml" line="418"/>
         <source> on </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="511"/>
+        <location filename="../VideoInfoView.qml" line="484"/>
         <source>Views</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="525"/>
+        <location filename="../VideoInfoView.qml" line="498"/>
         <source>Description</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="541"/>
+        <location filename="../VideoInfoView.qml" line="514"/>
         <source>Tags</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="611"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source>No comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="611"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source> comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="704"/>
+        <location filename="../VideoInfoView.qml" line="677"/>
         <source>No related videos</source>
         <translation></translation>
     </message>
@@ -1186,49 +1071,11 @@
 <context>
     <name>VideoListView</name>
     <message>
-        <location filename="../VideoListView.qml" line="57"/>
-        <source>Multi-select</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoListView.qml" line="59"/>
-        <source>Download video</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoListView.qml" line="59"/>
-        <source>Download audio</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoListView.qml" line="60"/>
-        <source>Add to favourites</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoListView.qml" line="60"/>
-        <source>Add to playlist</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoListView.qml" line="60"/>
-        <source>Copy to clipboard</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../VideoListView.qml" line="114"/>
+        <location filename="../VideoListView.qml" line="72"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>Widget</name>
-    <message>
-        <location filename="../Widget.qml" line="287"/>
-        <source>No videos found</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>YouTube</name>
     <message>
@@ -1237,45 +1084,45 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="50"/>
+        <location filename="../../../youtube.cpp" line="55"/>
         <source>Authentication failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="53"/>
+        <location filename="../../../youtube.cpp" line="59"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="116"/>
-        <location filename="../../../youtube.cpp" line="222"/>
+        <location filename="../../../youtube.cpp" line="121"/>
+        <location filename="../../../youtube.cpp" line="227"/>
         <source>Error - Server repsonse is: </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="166"/>
-        <location filename="../../../youtube.cpp" line="174"/>
+        <location filename="../../../youtube.cpp" line="171"/>
+        <location filename="../../../youtube.cpp" line="179"/>
         <source>Upload aborted</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="181"/>
+        <location filename="../../../youtube.cpp" line="186"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="185"/>
+        <location filename="../../../youtube.cpp" line="190"/>
         <source>Upload failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="191"/>
+        <location filename="../../../youtube.cpp" line="196"/>
         <source>Upload is completed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="382"/>
-        <location filename="../../../youtube.cpp" line="419"/>
+        <location filename="../../../youtube.cpp" line="387"/>
+        <location filename="../../../youtube.cpp" line="424"/>
         <source>Error: Unable to retrieve video</source>
         <translation></translation>
     </message>
@@ -1283,97 +1130,97 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="109"/>
+        <location filename="../main.qml" line="111"/>
         <source>Video(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="120"/>
+        <location filename="../main.qml" line="122"/>
         <source>Audio track(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="151"/>
+        <location filename="../main.qml" line="153"/>
         <source>Video added to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="152"/>
+        <location filename="../main.qml" line="154"/>
         <source>Video added to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="160"/>
+        <location filename="../main.qml" line="162"/>
         <source>New playlist created</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="204"/>
+        <location filename="../main.qml" line="206"/>
         <source>Audio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="209"/>
+        <location filename="../main.qml" line="211"/>
         <source>Conversion of &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="209"/>
+        <location filename="../main.qml" line="211"/>
         <source>&apos; failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="224"/>
+        <location filename="../main.qml" line="226"/>
         <source>High quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="224"/>
+        <location filename="../main.qml" line="226"/>
         <source>Mobile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="224"/>
+        <location filename="../main.qml" line="226"/>
         <source>360p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="224"/>
+        <location filename="../main.qml" line="226"/>
         <source>480p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="224"/>
+        <location filename="../main.qml" line="226"/>
         <source>720p</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="225"/>
+        <location filename="../main.qml" line="227"/>
         <source>Queued</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="225"/>
+        <location filename="../main.qml" line="227"/>
         <source>Paused</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="225"/>
+        <location filename="../main.qml" line="227"/>
         <source>Downloading</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="225"/>
+        <location filename="../main.qml" line="227"/>
         <source>Failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="422"/>
+        <location filename="../main.qml" line="395"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="423"/>
+        <location filename="../main.qml" line="396"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
@@ -1381,37 +1228,37 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="119"/>
+        <location filename="../scripts/mainscripts.js" line="123"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="134"/>
+        <location filename="../scripts/mainscripts.js" line="138"/>
         <source>Archive</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="173"/>
+        <location filename="../scripts/mainscripts.js" line="177"/>
         <source>My Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="183"/>
+        <location filename="../scripts/mainscripts.js" line="187"/>
         <source>My Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="196"/>
+        <location filename="../scripts/mainscripts.js" line="200"/>
         <source>Video Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="206"/>
+        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>Video Playback</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="218"/>
+        <location filename="../scripts/mainscripts.js" line="223"/>
         <source>Search </source>
         <translation></translation>
     </message>
