@@ -36,14 +36,19 @@ function showVideoDialog(index) {
 }
 
 function showPlaylistDialog() {
-    if (dimmer.state == "") {
-        toggleControls(false);
-        var playlistDialog = ObjectCreator.createObject("AddToPlaylistDialog.qml", window);
-        playlistDialog.playlistClicked.connect(addVideosToPlaylist);
-        playlistDialog.close.connect(closeDialogs);
-        dimmer.state = "dim";
-        playlistDialog.state = "show";
-        mouseArea.enabled = true;
+    if (userIsSignedIn()) {
+        if (dimmer.state == "") {
+            toggleControls(false);
+            var playlistDialog = ObjectCreator.createObject("AddToPlaylistDialog.qml", window);
+            playlistDialog.playlistClicked.connect(addVideosToPlaylist);
+            playlistDialog.close.connect(closeDialogs);
+            dimmer.state = "dim";
+            playlistDialog.state = "show";
+            mouseArea.enabled = true;
+        }
+        else {
+            displayMessage("You are not signed in to a YouTube account");
+        }
     }
 }
 
@@ -85,11 +90,17 @@ function addVideosToPlaylist(playlistId) {
 }
 
 function addVideosToFavourites() {
-    for (var i = 0; i < videoList.checkList.length; i++) {
-        var videoId = videoListModel.get(videoList.checkList[i]).videoId;
-        toggleBusy(true);
-        YouTube.addToFavourites(videoId);
+    if (userIsSignedIn()) {
+        for (var i = 0; i < videoList.checkList.length; i++) {
+            var videoId = videoListModel.get(videoList.checkList[i]).videoId;
+            toggleBusy(true);
+            YouTube.addToFavourites(videoId);
+        }
     }
+    else {
+        displayMessage("You are not signed in to a YouTube account");
+    }
+
     videoList.checkList = [];
 }
 
